import argparse
import logging
import os


def get_parser():
    parser = argparse.ArgumentParser(description="hashdir")

    parser.add_argument("directory", nargs="?", default=".")

    parser.add_argument(
        "-a",
        "--algorithm",
        choices=["md5", "sha1", "imohash"],
        default="md5",
        help="warning: imohash is a constant-time hashing library, "
        "and while being fast for large files, it produces approximate results.",
    )

    parser.add_argument(
        "--log-level", choices=["error", "info", "debug"], default="info"
    )

    return parser


def parse_args(args):
    argument_parser = get_parser()
    args = argument_parser.parse_args(args)
    valid = validate_args(args)
    if valid:
        return args
    else:
        argument_parser.print_help()
        return None


def validate_args(args):
    if not os.path.isdir(args.directory):
        print("dir ", args.directory)
        logging.error("provided path is not a directory.")
        return False
    return True



import hashlib
import imohash


def hash_file_imohash(filepath):
    return imohash.hashfile(filepath, hexdigest=True)


def hash_file_md5(filepath):
    hash_obj = hashlib.md5()
    return hash_file_hashlib(filepath, hash_obj)


def hash_file_sha1(filepath):
    hash_obj = hashlib.sha1()
    return hash_file_hashlib(filepath, hash_obj)


def hash_file_hashlib(filepath, hash_obj):
    READ_CHUNK_SIZE = 4096
    with open(filepath, "rb") as f:
        while 1:
            buf = f.read(READ_CHUNK_SIZE)
            if not buf:
                break
            hash_obj.update(hashlib.md5(buf).hexdigest().encode())
    return hash_obj.hexdigest()
